==============================
Introduction
==============================

Learning Moroccan Arabic
++++++++++++++++++++++++++++++

Even under the best conditions, learning a new language can be challenging. Add to this challenge the rigors of Peace Corps training, and you’re faced with what will be one of the most demanding — and rewarding — aspects of your Peace Corps experience: learning to communicate with Moroccans in their own language. But it can be done. And rest assured that you can do it. Here are a few reasons why:

-  **You are immersed in the language**: Some people may need to hear a word three times to remember it; others may need thirty. Learning Moroccan Arabic while living and training with Moroccans gives you the chance to hear the language used again and again.
-  **You have daily language classes with Moroccan teachers**: You’re not only immersed in the language; you also have the opportunity to receive feedback from native speakers on the many questions that predictably crop up when one learns a new language.
-  **Peace Corps has over forty years of experience in Morocco**: Your training, including this manual, benefits from the collective experience gained by training thousands of Americans to live and work in Morocco. You will benefit from and contribute to that legacy.

Despite these advantages, at times you may still feel like the task of learning Moroccan Arabic is too much to handle. Remember that volunteers like you have been doing it for decades, however. One of the most rewarding aspects of your time will be communicating with Moroccans in Arabic, surprising them and yourself with how well you know the language. When that time arrives, your hard work will have been worth it.

Transcription of Moroccan Arabic
++++++++++++++++++++++++++++++++

In order for trainees to move quickly into Moroccan Arabic (also called 'Darija'), Peace Corps uses a system of transcription that substitutes characters of the Latin alphabet (a, b, c, d ...) for characters from Arabic script (... :ar:`أ ب ت ج`). With this system, it isn’t necessary for a trainee to learn all of Arabic script before he or she begins to learn the language. On the contrary, once you become familiar with the system of transcription, you will be able to “read” and “write” Moroccan Arabic fairly quickly — using characters you are familiar with. You will also learn Arabic script during training, but with transcription it isn’t necessary to know it right away. Throughout the book, therefore, you will always see both the original Arabic script and the transcription. Becoming familiar with the Peace Corps’ system of transcription is one of the best things you can do, early on, to help yourself learn Moroccan Arabic. Practicing the different sounds of Moroccan Arabic until you can reproduce them is another. This introduction is intended mainly to help you get started with the system of transcription, and as a result it will mention only briefly the different sounds of Arabic. However, a fuller explanation can be found at :ref:`Pronunciation of Moroccan Arabic`.

Sounds You Already Know
------------------------------

The large majority of consonants in Moroccan Arabic are similar to sounds that we have in English. The vowels in Arabic are also similar to English vowels. In the following table, each transcription character that represents a sound you already know will be explained. The sounds are not necessarily what you may expect, but each character was matched with a sound for good reasons.

.. list-table:: Transliteration Table
   :widths: auto
   :header-rows: 1

   * - Transc.
     - Arabic
     - Description
   * - a
     - :arb:`أ /  َ / ى`
     - sometimes the /ä/ in 'father', sometimes the /a/ in 'mad'
   * - b
     - :arb:`ب`
     - normal English sound /b/
   * - d
     - :arb:`د`
     - normal English sound /d/
   * - e
     - :arb:`َ  / ا`
     - short /e/ sound as in 'met' (not used often, only to avoid confusion with 'a')
   * - f
     - :arb:`ف`
     - normal English sound /f/
   * - g
     - :arb:`گ`
     - normal English sound /g/ as in 'go'
   * - h
     - :arb:`ه`
     - normal English sound /h/ as in 'hi'
   * - i
     - :arb:`ي / ِ`
     - long /ee/ sound as in 'meet'
   * - j
     - :arb:`ج`
     - /zh/ sound as 's' in 'pleasure'
   * - k
     - :arb:`ك`
     - normal English sound /k/
   * - l
     - :arb:`ل`
     - normal English sound /l/
   * - m
     - :arb:`م`
     - normal English sound /m/
   * - n
     - :arb:`ن`
     - normal English sound /n/
   * - o
     - :arb:`و`
     - long /o/ as in 'bone' (not used often, mainly for French words)
   * - p
     - :arb:`پ`
     - normal English sound /p/
   * - r
     - :arb:`ر`
     - **not** the normal English /r/, similar to Spanish /r/, or 'tt' in 'I gotta go'
   * - s
     - :arb:`س`
     - normal English sound /s/
   * - t
     - :arb:`ت`
     - normal English sound /t/
   * - u
     - :arb:`و`
     - long 'oo' /ü/ as in 'food'
   * - v
     - :arb:`ڤ`
     - normal English sound /v/
   * - w
     - :arb:`و`
     - normal English sound /w/
   * - y
     - :arb:`ي`
     - normal English sound /y/
   * - z
     - :arb:`ز`
     - normal English sound /z/
   * - sh / š
     - :arb:`ش`
     - normal English sound /sh/ as in 'she'
   * - Some 
     - vowel
     - combinations
   * - ay
     - :arb:`اي`
     - 'ay' as in 'say'
   * - au
     - :arb:`او`
     - 'ow' as in 'cow'
   * - iu
     - :arb:`يو`
     - 'ee you' as in 'see you later'
     
New Sounds
------------------------------

There are eight consonants in Moroccan Arabic that we do not have in English. It may take you some time to be able to pronounce these correctly. At this point, what’s important is that you learn the transcription character for each of these sounds. See :ref:`Pronunciation of Moroccan Arabic` for more information on how to pronounce the sounds in Moroccan Arabic.

.. note::
   First three sounds in the table below are pronounced like their non-emphatic counterparts, but with a lower pitch and a greater tension in the tongue and throat.

.. list-table:: Transliteration Table of New Sounds
   :widths: auto
   :header-rows: 1

   * - Transc.
     - Arabic
     - Description
   * - D / ḍ
     - :arb:`ض`
     - Arabic emphatic 'd' (see note above)
   * - S / ṣ
     - :arb:`ص`
     - Arabic emphatic 's' (see note above)
   * - T / ṭ
     - :arb:`ط`
     - Arabic emphatic 't' (see note above)
   * - q
     - :arb:`ق`
     - like the English /k/ but pronounced further back in the throat
   * - kh / x
     - :arb:`خ`
     - like the 'ch' in German 'Bach'; like 'yech!'
   * - gh / ġ
     - :arb:`غ`
     - like the 'x' sound above, similar to French 'r'
   * - 7 / H
     - :arb:`ح`
     - like the English 'h', pronounced deep in the throat as a loud raspy whisper
   * - 3 / Ꜫ
     - :arb:`ع`
     - difficult at first; close to pronouncing 'a' in 'fat' with tongue against the bottom, from deep in the throat

Shedda
------------------------------

.. note:: Shaddah
   Wiki says `Shaddah <https://en.wikipedia.org/wiki/Shaddah>`_. ّ  - utf-8: U+0651.   

If you see a transcription character doubled, that means that a *shedda* is over that character in the Arabic script. For example, in the following table, you will see how the transcription changes for *shedda*, and thus the pronunciation.

.. list-table::
   :widths: auto
   :header-rows: 1

   * - English
     - Transc.
     - Arabic
   * - woman
     - mra
     - مرا
   * - time (i.e. 'i've seen him one time')
     - mrra
     - مرّة

.. note::
   The small character, which looks like a 'w', is the shedda. That is why the transcription has a double 'r'.

Notice that these two words are spelled differently in the transcription. The word 'woman' does not have a shedda on the 'r' in Arabic script, and that is why there is only one 'r' in the transcription. The word 'time' does have a shedda in the Arabic script, and that is why the transcription doubles the letter 'r'. These two words are pronounced differently, so you must pay attention to doubled letters in transcription. To learn more about how we pronounce the shedda in Arabic, see :ref:`Pronunciation of Moroccan Arabic`. For now, what’s important is that you understand the transcription.

Other Symbols
------------------------------

Sometimes, you will see a hyphen used in the transcription. This has three purposes:

1. **It indicates the definite article**: For some letters, the definite article (the word “the”) is made by adding the letter “l.” For others, it is made by doubling the first letter. In both cases, a hyphen will be used to indicate to you that the word has the definite article in front of it. See :ref:`Pronunciation of Moroccan Arabic` for more info on the definite article.

2. **It connects the present tense prefix**: The present tense prefix (“kan,” “kat,” or “kay”) will be connected to the verb with a hyphen. This will make it easier for you to understand what verb you are looking at.

3. **It connects the negative prefix (“ma”) and the negative suffix (“sh”) to a verb**.

In these instances, the hyphen does not necessarily indicate a change in pronunciation. The hyphen is there to make it easy for you to see when a definite article is being used, for example, or which verb is being used. It is a visual indicator, not an indicator of pronunciation. Sometimes the rhythm of speech may seem to break with the hyphen; other times the letters before and after the hyphen will be pronounced together.

Another symbol you will sometimes see is the **capital** (A). When you see an apostrophe, it indicates a 'glottal stop', which is the break between vowels as heard in the English exclamation 'uh oh'. That is to say, if you see an apostrophe you should not connect the sounds before the apostrophe with the sounds after the apostrophe. Pronounce them with a break in the middle.

Words & Syllables Without Vowels
--------------------------------

Sometimes you will see syllables or even whole words without any vowels written in them. This is normal in Moroccan Arabic. To the English speaker, however, this seems impossible, since we have always been taught that all words must contain a vowel sound. Which side is correct? Well, in a sense they both are. In reality, it is indeed possible to pronounce consonants together without articulating a vowel sound; we do it a lot in English at the beginning of words. Think about the word *street*. We pronounce three consonants — s, t, and r — without any vowels between them. So it is possible. The only challenge with Arabic is that the consonant combinations are new for English speakers (we don’t put the /sh/ sound next to the /m/ sound, for example, but in Arabic they do).

However, try for a moment to pronounce only the letters 'str', not the whole word 'street'. In this case, most English speakers will hear something that sounds like the word 'stir'. With certain consonant combinations, that is to say, it sounds to the English speaker like there is a vowel in the middle, even if there isn’t. The 'vowel' is in reality just the normal sound made as one consonant sound transitions to another.

Part of learning Moroccan Arabic is becoming comfortable with new consonant combinations and practicing those combinations without necessarily placing a vowel in the middle. The transcription words, you will notice, only include characters for vowels when there really is a vowel in the word. It may seem difficult at first, but it is better to accustom yourself to this as early as you can.

All of this concerns a larger point: **the transcription system used in this book may appear complex at first, but it has been carefully thought out** and in the end it is the easiest system possible. That said, the sooner you can make the transition to reading Arabic script, the easier it will be.
