================================
Pronunciation of Moroccan Arabic
================================

Despite what you may think at first, it is indeed possible for you to learn how to pronounce the sounds of Moroccan Arabic. Learning to pronounce Arabic sounds correctly entails two things: first, becoming aware of how to make the different sounds and, second, practicing with a native speaker. This chapter will help you with the first task.

Understanding How Sounds Are Made
+++++++++++++++++++++++++++++++++

Before we move directly into how to pronounce Arabic sounds, let’s first understand how sounds are made in general. Then we can use this knowledge in order to work on Arabic sounds.

Fricatives and Stops
------------------------------

Make the /s/ sound. Notice how air is being forced through the space between your tongue and the gum ridge in your mouth. When a sound is produced like this, by forcing air between some small opening, that sound is called a **fricative**. Make the /f/ sound. This sound is also a fricative, because in order to make it we must force air between our teeth and our bottom lip. Some sounds in English that are fricatives are: /s/, /z/, /sh/, /th/, /f/, /v/, and others.

Now make the /t/ sound. Here, we are not forcing air through a small opening at a constant pressure, but rather we completely block the air flow for a moment, and then release the air stream in one big burst. A sound that is produced by blocking the air flow, and then releasing it, is called a **stop**. Make the /k/ sound. This is another “stop” because again, you will notice how we build up a lot of pressure with air, and then release it. Some stops in English are: /t/, /k/, /g/, /b/, /p/, and others.

.. note::
   The /t/ sound is voiceless and the /d/ sound is voiced. Both are “stops”.

Voiced and Voiceless Sounds
------------------------------

We can also categorize consonant sounds according to whether we use our voice box or not. Make the /s/ sound. While making the sound, hold your hand over your throat. Now make the /z/ sound, still holding your hand to your throat. You’ll notice that with /s/, we don’t use our voice box, but with /z/, our voice box vibrates. Sounds like /s/ are called voiceless, since we don’t use our voice box. Sounds like /z/ are called voiced, since our voice box vibrates. Make the sound /t/. Is it voiceless or voiced? Now make the sound /d/. Voiceless or voiced?

Let’s look now at some of the difficult Arabic sounds, using what we know about sounds in general.

Pronunciation of Non-English Consonants
+++++++++++++++++++++++++++++++++++++++

The Sound 'q' (ق)
------------------------------

The q sound is similar to the 'k' sound. Both are voiceless 'stops' that are made by releasing air forcefully after completely blocking the air flow momentarily. The only difference is where in the throat the speaker blocks the air flow. The 'q' sound will be made further back in the throat than the 'k' sound. Try the following exercise.

First, take a minute to become more familiar with your throat muscles. Open your mouth and say `aah`, as if you were at the doctor’s office. Your tongue should be flat in your mouth. Without raising your tongue, pull it back so that the base of your tongue closes off air by pulling back against the throat. At this point, you should not be able to breathe through your mouth, although it is wide open. Practice doing this first without making a sound. After performing this exercise several times, make a sound by releasing the air forcefully. The result will be the sound 'q'.

The Sound 'kh/x' (خ)
------------------------------

The sound 'x' is a voiceless fricative formed around the same place as the sound 'q'. It is found in many European languages: the Russian `kh/x`, the Scottish pronunciation of `loch`, and the German `ch` as pronounced after a back vowel as in `Bach`. Some people use this sound to say `yech!` To pronounce 'kh/x', make the sound 'q' and pay attention to where the back of your tongue hits the back of the roof of your mouth and blocks your windpipe. Instead of closing off the windpipe with the back of your tongue completely, block it part way, and you will produce this sound.

The Sound 'gh/ġ' (غ)
------------------------------

The sound 'gh/ġ' is the same sound as the sound 'kh/x', except it is “voiced”. In other words, if you can make the sound 'kh/x', all you need to do is vibrate your voice box at the same time, and you will produce 'gh/ġ'. Think of the correspondence between the sounds 'k' (kite) and 'g' (game): 'k' is voiceless and 'g' is voiced. Pronounce 'k' and 'g' several times, paying attention to how your voice changes when you say 'g'. Now say 'kh/x' several times, and then “voice” it. The result is 'gh/ġ'.

Alternatively, you may think of 'gh/ġ' as similar to the sound you make when gargling. Gargle for a minute and pay attention to the muscles you use. The sound 'gh/ġ' is pronounced using these same muscles in similar fashion.

The Emphatic Sounds 'S/ṣ' (ص) 'D/ḍ' (ض), and 'T/ṭ' (ط)
------------------------------------------------------

The sound 'S/ṣ' is the emphatic counterpart of the sound 's'. Pronounce the sound 's' aloud, and note the position of your tongue. It should be toward the front of the mouth and high, close to the roof. Now, starting at the back of your teeth, move your tongue back along the roof of your mouth. You will find a bony ridge just behind the teeth, before the upward curve of the roof. Put your tongue against this ridge. The rest of your tongue will drop lower inside your mouth. The emphatic or velarized consonants in Arabic are pronounced by placing the tip of your tongue in this spot and dropping the rest of the tongue as low as you can. Thus, the sounds 'S/ṣ', 'D/ḍ', and 'T/ṭ' are all made with the tongue in this position.

All the emphatic sounds are lower in pitch than their non-emphatic counterparts. They are pronounced with greater muscular tension in the mouth and throat and with a raising of the back and root of the tongue toward the roof of the mouth. You can notice this contraction of the throat easily by prolonging the 'l' in 'full'.

One important note about the emphatic sounds: they deepen the sound of surrounding vowels. Pay attention to the sound of all vowels near these emphatic sounds, because the quality of the vowels gives the best indication of the presence of emphatic consonants. One important example is **Ɛṭini**, 'give me' in Moroccan Arabic. Most trainees will hear the word and think it is pronounced **Ɛṭayni**, with the middle vowel sound 'ay' instead of 'i'. This is because the emphatic sound 'T/ṭ' affects the way the 'i' sounds, making it sound (to the English speaker’s ear) like an 'ay'. It is, in fact, an 'i' however.

The Sound '7/H' (ح)
------------------------------

The sound '7/H' is a voiceless fricative pronounced deep in the throat. It has no equivalent in English. In order to practice this sound, first take a few minutes to become better acquainted with some of your throat muscles that you use often, but not to speak English. The following exercises are designed to make you aware of what these muscles can already do, so that you can use them to speak Arabic. Practice them for a few minutes every day, as often as you can.

1. With your mouth closed, block off your windpipe at your throat. Put your hand on your throat at the Adam’s apple and constrict the muscles on the inside. You should be able to feel the muscles contracting. Alternately tighten and relax them for a few minutes.

2. Repeat this with your mouth open. Try to breathe out through your mouth — if you can, you are not closing off the windpipe entirely.

3. Constrict those same muscles so that air can just barely squeeze through your throat. Imitate someone fogging a pair of glasses to clean them. The sound of the air coming through your constricted throat muscles is '7/H'. By now, you should be aware of what your throat muscles are doing.

4. Bend your head down so that your chin rests on the top of your chest, and repeat exercise 3. This position should make it easier for you to feel what you are doing.

Pronouncing '7/H' takes practice, first to pronounce the letter alone, and then to pronounce it surrounded by other letters in a word. You must learn to pronounce it properly to be understood, and at first, this will take some concentration on your part. However, the more you practice now, the sooner you will be able to say it easily.

The Sound '3/Ɛ' (ع)
------------------------------

We now come to one of the most distinctive sounds in Arabic: '3/Ɛ'. When pronounced correctly, '3/Ɛ' has its own unique beauty and can be a very expressive sound. It is not as difficult to pronounce as one may first think, but you need to exercise your throat muscles, the same ones that you use to pronounce '7/H'. You should continually be doing the exercises you learned above for '7/H', in which you constricted your throat muscles as if you were blocking off the air passage from the inside. You can feel this by putting your hand on your throat. Say '7/H', and feel the muscles contract. Now pronounce the same sound and 'voice' it. That is, say the sound while vibrating your voice box, changing the breathy sound of '7/H' into the deep, throaty sound of '3/Ɛ'. The sounds '7/H' and '3/Ɛ' are only different because '7/H' is voiceless and '3/Ɛ' is voiced.

Some trainees think that '3/Ɛ' sounds like a vowel, but it is not a vowel. Because we constrict our throat muscles and force air through the passageway, the sound '3/Ɛ' is a fricative. Vowels do not force air through a partially blocked passageway, and thus cannot be fricatives.

The Arabic 'r' (ر)
------------------------------

The sound 'r' in Arabic is not the same as the English 'r'. It is not difficult, like some of the other sounds above may seem at first. But because it is new, we include here a short description of it. The sound is a flap, like the Spanish or Italian 'r'. You already know how to make this sound: it is the sound American English speakers make saying 'gotta' as in 'gotta go'. Say 'gotta' several times in a row very quickly and pay attention to what your tongue is doing. You should feel it flapping against the roof of your mouth behind your teeth. Now pronounce the sound alone. Another good exercise is to practice making a whirring sound: `rrrrrrrrrrrrrrr`. Do these exercises daily until you have mastered this
sound.

Pronunciation of Shedda
++++++++++++++++++++++++++++++

In Arabic, a *shedda* is a pronounced stress upon a letter in a word. In transcription, this stress is indicated by doubling of a consonant. When there is *shedda*, it indicates that the consonant is to be held twice as long as a normal consonant. That is, it should be pronounced for twice the length of time. This is easy with fluid sounds like 'z' or 'r'. With sounds like 'b' or 'd', however, you must begin to say them and pause in the middle of pronouncing them for a second. This may take some practice at first.

In English, this doubling of a consonant sound never occurs in the middle of words, but is very common from the end of one word to the beginning of another. Compare the difference between the single 'd' in 'lay down' and the double 'dd' in 'laid down'. Noticing the difference between the single 'd' and double 'dd' in this example will give you some idea of how a *shedda* affects pronunciation.

It cannot be stressed enough that *shedda* affects not only the pronunciation of a word, but also its meaning, especially for verbs. Recognizing when *shedda* is used and learning to pronounce it correctly yourself is an important task in your study of Moroccan Arabic.

The Definite Article
++++++++++++++++++++++++++++++

In English, the 'definite article' is the word 'the'. It is different from the 'indefinite articles', which are 'a' and 'an'. In English, the definite article speaks about something specific: I washed the dog today (you know which dog I’m speaking about). The indefinite articles talk about something non-specific: I saw a dog today (you don’t know the dog I’m speaking about). In Arabic, the definite article is not always used exactly as in English. When written in Arabic script, it is composed of two letters, **al** (ال), attached to the beginning of a noun or an adjective. Here is the Arabic script for 'the book':

الكتاب -> first 2 letters (from the right, of course) are the definite article

These two letters are always written in Arabic script for a definite article, but they are not always pronounced. In Moroccan Arabic, the first letter, **a** (ا), is never pronounced. Two possibilities exist, therefore, for pronouncing the definite article. Sometimes, the second letter **l** (ل) is pronounced. Other times, instead of pronouncing the **l**, the first letter of the word is doubled with a *shedda*. Whether the definite article is pronounced with 'l' or by doubling the first letter with *shedda* is determined by which letter is the *first letter of the word*. Let’s look at these two different possibilities.

The Moon Letters
------------------------------

In the first possibility, the Arabic definite article is pronounced with an 'l' (ل) at the beginning of a word. All words that begin with the following letters follow this rule:

.. list-table::
   :widths: auto
   :header-rows: 0

   * - i/y
     - u/w
     - h
     - m
     - k
     - q
     - f
     - gh
     - 3/Ɛ
     - kh
     - 7/H
     - b
     - a
   * - ي
     - و
     - ه
     - م
     - ك
     - ق
     - ف
     - غ
     - ع
     - خ
     - ح
     - ب
     - ا

These letters are called **moon letters**, because the Arabic word for moon, **qamar**, begins with one of the letters in the group. Notice in the following examples that the definite article is pronounced by adding an 'l' to the word:

.. list-table::
   :widths: 10 10 10 5 10 10 10
   :header-rows: 0

   * - a book
     - ktab
     - كتاب
     - |
     - a girl
     - bnt
     - بنت
   * - the book
     - l-ktab
     - الكتاب
     - |
     - the girl
     - l-bnt
     - البنت
   * - a boy
     - wld
     - ولد
     - |
     - a moon
     - qamar
     - قَمَر
   * - the boy
     - l-wld
     - الولد
     - |
     - the moon
     - l-qamar
     - القَمَر

The Sun Letters
------------------------------

In the second possibility, the Arabic definite article is pronounced by doubling the first letter of a word with a *shedda*. All words that begin with the following letters follow this rule:

.. list-table::
   :widths: auto
   :header-rows: 0

   * - n
     - l
     - T
     - D
     - S
     - sh
     - s
     - z
     - r
     - j
     - t
   * - ن
     - ل
     - ط
     - ض
     - ص
     - ش
     - س
     - ز
     - ر
     - ج
     - ت

These letters are known as **sun letters**, because the Arabic word for sun, **šms**, begins with one of the letters in the group. Notice in the following examples that the definite article is pronounced by doubling the first letter of the word by using *shedda*.

.. note::
   I can not, for all my knowledge, find *shaddah* in below text.

.. list-table::
   :widths: 10 10 10 5 10 10 10
   :header-rows: 0

   * - a house
     - Dar
     - دار
     - |
     - a street
     - znqa
     - زنقة
   * - the house
     - D-Dar
     - الدار
     - |
     - the street
     - z-znqa
     - الزنقة
   * - a man
     - rajl
     - راجل
     - |
     - a sun
     - shms
     - شمس
   * - the man
     - r-rajl
     - الراجل
     - |
     - the sun
     - sh-shms
     - الشمس
